Welcome to ROVEaC's documentation!
===================================

**ROVEaC** is a Python library for counterexample
checking and one-vertex extension of Ramsey theory
candidate graphs. It offers a *simple* and *intuitive* API
that can be leveraged with counterexample sets, such as those
offered by `Brendan McKay <https://users.cecs.anu.edu.au/~bdm/data/ramsey.html>`_

Check out the :doc:`usage` section for further information, including
how to :ref:`installation` the project.

.. note::

   This project is under active development.

Contents
--------

.. toctree::

   usage
   api
